magneticalc.File_Menu.File_Menu

# ``magneticalc`.`File_Menu`.`File_Menu``

class documentation

`class File_Menu(QMenu):`

Constructor: `File_Menu(gui)`

View In Hierarchy

File_Menu class.

Method | `__init__` | Initializes the menu.
Method | `close_project` | Closes the project and loads the default project.
Method | `export_image` | Exports the currently displayed scene to a PNG file.
Method | `new_project` | Creates a new project with an INI file.
Method | `open_project` | Opens a project from an INI file.
Method | `save_project_as` | Saves the project to an INI file.
Method | `update` | Updates the menu.
Instance Variable | `gui` | Undocumented

def __init__(self, gui: `GUI`):

Initializes the menu.

def close_project(self):

Closes the project and loads the default project.

def export_image(self):

Exports the currently displayed scene to a PNG file.

def new_project(self):

Creates a new project with an INI file.

def open_project(self):

Opens a project from an INI file.

def save_project_as(self):

Saves the project to an INI file.

def update(self):

Updates the menu.

gui =

Undocumented